@@ -1,4 +1,4 @@
 default_app_config = "structures.apps.StructuresConfig"
 
-__version__ = "1.3.3"
-__title__ = "Alliance Structures"
+__version__ = "1.3.4"
+__title__ = "Structures"
